GetClosestSamples: Get n samples

Description Usage Arguments Value

View source: R/closesamples.R

Description

Get n samples

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
GetClosestSamples(
  n,
  phy_full,
  taxa_feasible,
  replace_full = TRUE,
  replace_feasible = FALSE,
  truncate_full_to_mrca = FALSE,
  less_memory = FALSE,
  descendant_labeled = FALSE,
  fast_ultrametric = FALSE,
  verbose = TRUE
)

Arguments

n

How many taxa to sample

phy_full

A phylo object with all feasible taxa to sample from

taxa_feasible

A vector of taxon names that are feasible to study (often on another tree)

replace_full

If TRUE, will allow selecting the same taxon from the full tree more than once. If FALSE, forbids this. Both cases return n taxa

replace_feasible

If TRUE, will allow selecting the same taxon from the set of feasible taxa more than once (returning a smaller than desired tree). If FALSE, forbids this.

truncate_full_to_mrca

If TRUE, prune the full tree to the node that is the MRCA of the

less_memory

If TRUE, uses a much slower approach that will not create giant matrices

descendant_labeled

If TRUE, assumes the phy_full has been labeled with LabelNodesWithFeasibleDescendants

fast_ultrametric

If TRUE, uses a fast algorithm for ultrametric trees

verbose

If TRUE, all the output will print to the screen

Value

A data.frame of chosen taxa, closest feasible match, and distance between them


bomeara/closesamples documentation built on Nov. 14, 2021, 9:48 a.m.