GetSimilarity: Get similarity Uses ape's cophenetic.phylo to get patristic...

Description Usage Arguments Value

View source: R/closesamples.R

Description

Get similarity Uses ape's cophenetic.phylo to get patristic distances between pairs of taxa, then makes the diagonals Inf. If the tree has no branch lengths, makes every edge length 1.

Usage

1
GetSimilarity(phy_full, taxa_feasible, truncate_full_to_mrca = FALSE)

Arguments

phy_full

A phylo object with all feasible taxa to sammple from

taxa_feasible

A vector of taxon names that are feasible to study (often on another tree)

truncate_full_to_mrca

If TRUE, prune the full tree to the node that is the MRCA of the

Value

A matrix with tips on the rows and columns and patristic distances in the cells. Rows are tips on the phy_full tree, columns are taxa in the taxa_feasible vector


bomeara/closesamples documentation built on Nov. 14, 2021, 9:48 a.m.