SubsampleTree: Return a sampled tree

Description Usage Arguments Value

View source: R/closesamples.R

Description

Return a sampled tree

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
SubsampleTree(
  phy_feasible,
  n,
  phy_full = NULL,
  replace_full = TRUE,
  replace_feasible = FALSE,
  truncate_full_to_mrca = FALSE,
  less_memory = FALSE,
  verbose = TRUE
)

Arguments

phy_feasible

The tree to subsample

n

The number of taxa to include

phy_full

The larger tree giving relationships

replace_full

If TRUE, will allow selecting the same taxon from the full tree more than once. If FALSE, forbids this. Both cases return n taxa

replace_feasible

If TRUE, will allow selecting the same taxon from the set of feasible taxa more than once (returning a smaller than desired tree). If FALSE, forbids this.

truncate_full_to_mrca

If TRUE, prune the full tree to the node that is the MRCA of the feasible tree

less_memory

If TRUE, uses a much slower approach that will not create giant matrices

verbose

If TRUE, all the output will print to the screen

Value

A phylo object where taxa are sampled based on representing flat sampling from taxonomy


bomeara/closesamples documentation built on Nov. 14, 2021, 9:48 a.m.