Description Usage Arguments Value
Get n samples
1 2 3 4 5 6 7 8 9 10 11 12 |
n |
How many taxa to sample |
phy_full |
A phylo object with all feasible taxa to sample from |
taxa_feasible |
A vector of taxon names that are feasible to study (often on another tree) |
replace_full |
If TRUE, will allow selecting the same taxon from the full tree more than once. If FALSE, forbids this. Both cases return n taxa |
replace_feasible |
If TRUE, will allow selecting the same taxon from the set of feasible taxa more than once (returning a smaller than desired tree). If FALSE, forbids this. |
truncate_full_to_mrca |
If TRUE, prune the full tree to the node that is the MRCA of the |
less_memory |
If TRUE, uses a much slower approach that will not create giant matrices |
descendant_labeled |
If TRUE, assumes the phy_full has been labeled with LabelNodesWithFeasibleDescendants |
fast_ultrametric |
If TRUE, uses a fast algorithm for ultrametric trees |
verbose |
If TRUE, all the output will print to the screen |
A data.frame of chosen taxa, closest feasible match, and distance between them
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.