Description Usage Arguments Value
Return a sampled tree
1 2 3 4 5 6 7 8 9 10 |
phy_feasible |
The tree to subsample |
n |
The number of taxa to include |
phy_full |
The larger tree giving relationships |
replace_full |
If TRUE, will allow selecting the same taxon from the full tree more than once. If FALSE, forbids this. Both cases return n taxa |
replace_feasible |
If TRUE, will allow selecting the same taxon from the set of feasible taxa more than once (returning a smaller than desired tree). If FALSE, forbids this. |
truncate_full_to_mrca |
If TRUE, prune the full tree to the node that is the MRCA of the feasible tree |
less_memory |
If TRUE, uses a much slower approach that will not create giant matrices |
verbose |
If TRUE, all the output will print to the screen |
A phylo object where taxa are sampled based on representing flat sampling from taxonomy
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.